"use strict";
/**
 * (C) Copyright IBM Corp. 2022.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var ibm_cloud_sdk_core_1 = require("ibm-cloud-sdk-core");
var extend = require("extend");
var common_1 = require("../lib/common");
var EventNotificationsV1 = require("./v1");
var SendNotifications = /** @class */ (function (_super) {
    __extends(SendNotifications, _super);
    /**
     * Construct a EventNotificationsV1 object.
     *
     * @param {Object} options - Options for the service.
     * @param {string} [options.serviceUrl] - The base url to use when contacting the service. The base url may differ between IBM Cloud regions.
     * @param {OutgoingHttpHeaders} [options.headers] - Default headers that shall be included with every request to the service.
     * @param {Authenticator} options.authenticator - The Authenticator object used to authenticate requests to the service
     * @constructor
     * @returns {EventNotificationsV1}
     */
    function SendNotifications(options) {
        var _this = this;
        options = options || {};
        _this = _super.call(this, options) || this;
        if (options.serviceUrl) {
            _this.setServiceUrl(options.serviceUrl);
        }
        else {
            _this.setServiceUrl(SendNotifications.DEFAULT_SERVICE_URL);
        }
        return _this;
    }
    /*************************
     * Factory method
     ************************/
    /**
     * Constructs an instance of EventNotificationsV1 with passed in options and external configuration.
     *
     * @param {UserOptions} [options] - The parameters to send to the service.
     * @param {string} [options.serviceName] - The name of the service to configure
     * @param {Authenticator} [options.authenticator] - The Authenticator object used to authenticate requests to the service
     * @param {string} [options.serviceUrl] - The URL for the service
     * @returns {EventNotificationsV1}
     */
    SendNotifications.newInstance = function (options) {
        options = options || {};
        if (!options.serviceName) {
            options.serviceName = this.DEFAULT_SERVICE_NAME;
        }
        if (!options.authenticator) {
            options.authenticator = (0, ibm_cloud_sdk_core_1.getAuthenticatorFromEnvironment)(options.serviceName);
        }
        var service = new SendNotifications(options);
        service.configureService(options.serviceName);
        if (options.serviceUrl) {
            service.setServiceUrl(options.serviceUrl);
        }
        return service;
    };
    /*************************
     * sendNotifications
     ************************/
    /**
     * Send a notification.
     *
     * Send a notification.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.ibmenseverity - The Notifications id.
     * @param {string} params.ibmensourceid - The Event Notifications source id.
     * @param {string} params.subject - The Notifications subject.
     * @param {string} params.id - The Notifications id.
     * @param {string} params.source - The source of Notifications.
     * @param {string} params.type - The Notifications type.
     * @param {string} params.time - The Notifications time.
     * @param {JsonObject} [params.data] - The Notifications data for webhook.
     * @param {NotificationFCMBody} [params.ibmenfcmbody] -
     * @param {NotificationAPNSBody} [params.ibmenapnsbody] - Payload describing a APNs Notifications body.
     * @param {NotificationDevices} [params.ibmenpushto] - Payload describing a FCM Notifications targets.
     * @param {JsonObject} [params.ibmenapnsheaders] - The attributes for an FCM/APNs notification.
     * @param {string} [params.datacontenttype] - The Notifications content type.
     * @param {string} [params.specversion] - The Notifications specversion.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<SendNotifications.Response<SendNotifications.NotificationResponse>>}
     */
    SendNotifications.prototype.sendNotifications = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = [
            'instanceId',
            'ibmenseverity',
            'ibmensourceid',
            'subject',
            'id',
            'source',
            'type',
            'time',
        ];
        var _validParams = [
            'instanceId',
            'ibmenseverity',
            'ibmensourceid',
            'subject',
            'id',
            'source',
            'type',
            'time',
            'data',
            'ibmenfcmbody',
            'ibmenapnsbody',
            'ibmenpushto',
            'ibmenapnsheaders',
            'datacontenttype',
            'specversion',
            'headers',
        ];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var body = {
            'ibmenseverity': _params.ibmenseverity,
            'ibmensourceid': _params.ibmensourceid,
            'subject': _params.subject,
            'id': _params.id,
            'source': _params.source,
            'type': _params.type,
            'time': _params.time,
            'data': _params.data,
            'ibmenfcmbody': JSON.stringify(_params.ibmenfcmbody),
            'ibmenapnsbody': JSON.stringify(_params.ibmenapnsbody),
            'ibmenpushto': JSON.stringify(_params.ibmenpushto),
            'ibmenapnsheaders': JSON.stringify(_params.ibmenapnsheaders),
            'datacontenttype': 'application/json',
            'specversion': '1.0',
        };
        var path = {
            'instance_id': _params.instanceId,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(EventNotificationsV1.DEFAULT_SERVICE_NAME, 'v1', 'sendNotifications');
        var parameters = {
            options: {
                url: '/v1/instances/{instance_id}/notifications',
                method: 'POST',
                body: body,
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    SendNotifications.DEFAULT_SERVICE_URL = 'https://us-south.event-notifications.cloud.ibm.com/event-notifications';
    SendNotifications.DEFAULT_SERVICE_NAME = 'event_notifications';
    return SendNotifications;
}(ibm_cloud_sdk_core_1.BaseService));
module.exports = SendNotifications;
//# sourceMappingURL=sendNotification.js.map